labeltools.label_vertical_moments_in_expr_with_numbered_intervals
=================================================================

.. autofunction:: abjad.tools.labeltools.label_vertical_moments_in_expr_with_numbered_intervals.label_vertical_moments_in_expr_with_numbered_intervals
